@@ -8,7 +8,7 @@
 
 #include <asm/types.h>          /* For __uXX types */
 
-#define IP_VS_VERSION_CODE            0x000909
+#define IP_VS_VERSION_CODE            0x00090A
 #define NVERSION(version)                       \
 	(version >> 16) & 0xFF,                 \
 	(version >> 8) & 0xFF,                  \
@@ -605,7 +605,7 @@ extern struct ip_vs_conn *
 ip_vs_conn_new(int proto, __u32 maddr, __u16 mport, __u32 saddr,
 	       __u16 sport, __u32 daddr, __u16 dport, unsigned flags,
 	       struct ip_vs_dest *dest);
-#define ip_vs_conn_expire_now(cp)  cp->timer.function((unsigned long)cp)
+extern void ip_vs_conn_expire_now(struct ip_vs_conn *cp);
 
 extern const char * ip_vs_state_name(int state);
 extern int ip_vs_set_state(struct ip_vs_conn *cp, int state_off,
