@@ -5,11 +5,11 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.27 2002/01/24 14:23:48 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.28 2002/01/31 14:33:12 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
- *              Julian Anastasov <uli@linux.tu-varna.acad.bg>
+ *              Julian Anastasov <ja@ssi.bg>
  *
  *              This program is free software; you can redistribute it and/or
  *              modify it under the terms of the GNU General Public License
@@ -506,7 +506,7 @@ static int ip_vs_out_icmp(struct sk_buff **skb_p)
 	struct ip_vs_conn *cp;
 
 	/* reassemble IP fragments, but will it happen in ICMP packets?? */
-	if (skb->nh.iph->frag_off & htons(IP_MF|IP_OFFSET)) {
+	if (skb->nh.iph->frag_off & __constant_htons(IP_MF|IP_OFFSET)) {
 		skb = ip_defrag(skb);
 		if (!skb)
 			return NF_STOLEN;
@@ -654,7 +654,7 @@ static unsigned int ip_vs_out(unsigned int hooknum,
 		return NF_ACCEPT;
 
 	/* reassemble IP fragments */
-	if (iph->frag_off & htons(IP_MF|IP_OFFSET)) {
+	if (iph->frag_off & __constant_htons(IP_MF|IP_OFFSET)) {
 		skb = ip_defrag(skb);
 		if (!skb)
 			return NF_STOLEN;
@@ -977,8 +977,8 @@ static int ip_vs_in_icmp(struct sk_buff **skb_p)
 	/* MTU checking, is it necessary here??? */
 	mtu = rt->u.dst.pmtu;
 	if ((skb->len > mtu) && (iph->frag_off&__constant_htons(IP_DF))) {
-		icmp_send(skb, ICMP_DEST_UNREACH,ICMP_FRAG_NEEDED, htonl(mtu));
 		ip_rt_put(rt);
+		icmp_send(skb, ICMP_DEST_UNREACH,ICMP_FRAG_NEEDED, htonl(mtu));
 		IP_VS_DBG_RL("ip_vs_in_icmp(): frag needed\n");
 		goto tx_error;
 	}
@@ -1098,18 +1098,14 @@ static unsigned int ip_vs_in(unsigned int hooknum,
 		/* the destination server is not availabe */
 
 		if (sysctl_ip_vs_expire_nodest_conn) {
-			/* expire the connection immediately */
-			__ip_vs_conn_put(cp);
-			if (del_sltimer(&cp->timer))
-				ip_vs_conn_expire_now(cp);
-
-			return NF_DROP;
+			/* try to expire the connection immediately */
+			ip_vs_conn_expire_now(cp);
 		} else {
 			/* don't restart its timer, and silently
 			   drop the packet. */
 			__ip_vs_conn_put(cp);
-			return NF_DROP;
 		}
+		return NF_DROP;
 	}
 
 	ip_vs_in_stats(cp, skb);
@@ -1156,7 +1152,7 @@ static unsigned int ip_vs_forward_icmp(unsigned int hooknum,
 	if (iph->protocol != IPPROTO_ICMP)
 		return NF_ACCEPT;
 
-	if (iph->frag_off & htons(IP_MF|IP_OFFSET)) {
+	if (iph->frag_off & __constant_htons(IP_MF|IP_OFFSET)) {
 		skb = ip_defrag(skb);
 		if (!skb)
 			return NF_STOLEN;
