@@ -5,11 +5,11 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.24 2002/01/24 14:23:48 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.25 2002/01/31 14:33:12 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
- *              Julian Anastasov <uli@linux.tu-varna.acad.bg>
+ *              Julian Anastasov <ja@ssi.bg>
  *
  *              This program is free software; you can redistribute it and/or
  *              modify it under the terms of the GNU General Public License
@@ -376,14 +376,11 @@ ip_vs_service_get(__u32 fwmark, __u16 protocol, __u32 vaddr, __u16 vport)
 
 	read_lock(&__ip_vs_svc_lock);
 
-	if (fwmark) {
-		/*
-		 *	Check the table hashed by fwmark first
-		 */
-		svc = __ip_vs_svc_fwm_get(fwmark);
-		if (svc)
-			goto out;
-	}
+	/*
+	 *	Check the table hashed by fwmark first
+	 */
+	if (fwmark && (svc = __ip_vs_svc_fwm_get(fwmark)))
+		goto out;
 
 	/*
 	 *	Check the table hashed by <protocol,addr,port>
@@ -570,7 +567,6 @@ ip_vs_trash_get_dest(struct ip_vs_service *svc, __u32 daddr, __u16 dport)
 	/*
 	 * Find the destination in trash
 	 */
-
 	l = &ip_vs_dest_trash;
 
 	for (e=l->next; e!=l; e=e->next) {
